var indexSectionsWithContent =
{
  0: "abcdefghiklmnorstuvw~",
  1: "acdmrs",
  2: "s",
  3: "cdeflmrtv",
  4: "acdefghklmrstuvw~",
  5: "dkmnorstuv",
  6: "acfklmrst",
  7: "fst",
  8: "bcfgisv",
  9: "s",
  10: "d"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "defines",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Macros",
  10: "Pages"
};

